@@ -711,7 +711,6 @@ static void
 frameDrawWin (Client * c)
 {
     ScreenInfo *screen_info;
-    DisplayInfo *display_info;
     FramePixmap frame_pix;
     xfwmPixmap *my_pixmap;
     gint state, x, button, left, right;
@@ -728,15 +727,11 @@ frameDrawWin (Client * c)
     frameClearQueueDraw (c);
 
     screen_info = c->screen_info;
-    display_info = screen_info->display_info;
-
     requires_clearing = FALSE;
     width_changed = FALSE;
     height_changed = FALSE;
     state = ACTIVE;
 
-    myDisplayErrorTrapPush (display_info);
-
     if (c != clientGetFocus ())
     {
         TRACE ("\"%s\" is not the active window", c->name);
@@ -783,15 +778,15 @@ frameDrawWin (Client * c)
     }
     else
     {
-        if (c->previous_width != c->width)
+        if (c->frame_cache_width != c->width)
         {
             width_changed = TRUE;
-            c->previous_width = c->width;
+            c->frame_cache_width = c->width;
         }
-        if (c->previous_height != c->height)
+        if (c->frame_cache_height != c->height)
         {
             height_changed = TRUE;
-            c->previous_height = c->height;
+            c->frame_cache_height = c->height;
         }
     }
 
@@ -1049,8 +1044,6 @@ frameDrawWin (Client * c)
         }
         frameSetShape (c, 0, NULL, 0);
     }
-
-    myDisplayErrorTrapPopIgnored (display_info);
 }
 
 static gboolean
